@@ -10,26 +10,23 @@ import marshmallow as mm
 import pandas as pd
 
 
-__version__ = '3.1.7'
+__version__ = "3.2.1"
 
 authorizations = {
-    'apikey': {
-        'type': 'apiKey',
-        'in': 'query',
-        'name': 'middle_auth_token'
-    }
+    "apikey": {"type": "apiKey", "in": "query", "name": "middle_auth_token"}
 }
 
-api_bp = Namespace("EMAnnotation Schemas",
-                   authorizations=authorizations,
-                   description="EMAnnotation Schemas")
+api_bp = Namespace(
+    "EMAnnotation Schemas",
+    authorizations=authorizations,
+    description="EMAnnotation Schemas",
+)
 
 
 @api_bp.route("/type")
 class SchemasTypes(Resource):
-   
     @auth_required
-    @api_bp.doc('get_types', security='apikey')
+    @api_bp.doc("get_types", security="apikey")
     def get(self):
         return get_types()
 
@@ -42,10 +39,10 @@ def get_type_schema(annotation_type):
     json_schema = JSONSchema()
     return json_schema.dump(Schema())
 
+
 @api_bp.route("/type/<string:annotation_type>")
 class SchemaAnnotationType(Resource):
-   
     @auth_required
-    @api_bp.doc('get_annotation_type', security='apikey')
+    @api_bp.doc("get_annotation_type", security="apikey")
     def get(self, annotation_type: str):
         return get_type_schema(annotation_type)
